
import Link from 'next/link';
import style from "./button.module.css"
interface ButtonProps extends React.HTMLAttributes<HTMLElement> {
  variant?: 'primary' | 'light' | 'dark';
  size?: 'sm' | 'md';
  loading?: boolean;
  disabled?: boolean;
  href?: string;
  children: React.ReactNode;
}

export default function Button({
  variant = 'primary',
  size = 'md',
  loading = false,
  disabled = false,
  href,
  children,
  ...rest
}: ButtonProps) {
  // const classNames = cn(
  //   'inline-flex items-center font-medium uppercase focus:outline-none',
  //   {
  //     /** backgrounds */
  //     'bg-gray-200': disabled,
  //     'bg-primary text-light shadow-primary':
  //       !disabled && !outline && variant === 'primary',
  //     'bg-light text-dark shadow-light':
  //       !disabled && !outline && variant === 'light',
  //     'bg-dark text-light shadow-dark':
  //       !disabled && !outline && variant === 'dark',
  //     /** outline */
  //     'text-primary border-current border shadow-primary':
  //       !disabled && outline && variant === 'primary',
  //     'text-light border-current border shadow-light':
  //       !disabled && outline && variant === 'light',
  //     'text-dark border-current border shadow-dark':
  //       !disabled && outline && variant === 'dark',
  //     /** text */
  //     'text-gray-400': disabled,
  //     /* size */
  //     'text-sm px-8 py-3': size === 'sm',
  //     'text-base px-9 py-3': size === 'md',
  //     /** block */
  //     'w-full justify-center': block,
  //     /** hover, focus & active */
  //     'hover:shadow-xl focus:shadow-glow active:translate-y-0.5': !disabled
  //   }
  // );

  const classNames = `${style.btn} ${size === 'sm' ? style.sm : style.md}`
  return typeof href === 'string' ? (
    <Link href={href} className={classNames} {...rest}>
      {children}
      {loading && <Loader />}
    </Link>
  ) : (
    <button disabled={disabled} className={classNames} {...rest}>
      {children}
      {loading && <Loader />}
    </button>
  );
}

export function Loader() {
  return (
    <span className={style.loader}>
    </span>
  );
}
