"use client"
import style from "./todoapp.module.css"
import { useState, useEffect } from "react";
import Heading from "@/components/base/Heading/Heading";
import List from "@/components/layout/List/List";
import FormComponent from "@/components/Top-Level/Form/FormComponent";
import { TodoListItems } from "@/components/types";
import AddTask, { UpdateTask, DeleteTask } from "@/lib/Operation";
import getall from "@/lib/getall";
interface StateTodo {
    data?: TodoListItems[],
    isError: boolean;
    isLoading: boolean;
}

const Todo = () => {
    const [refresh, setrefresh] = useState<boolean>(false)
    const [TodoList, setTodoList] = useState<StateTodo>({
        isError: false,
        isLoading: true,
        data: []
    })
    useEffect(() => {
        (async () => {
            setTodoList(
                {
                    ...TodoList,
                    isLoading: true,
                }
            )

            const data = await getall();
            if (data) {
                setTodoList({
                    isError: false,
                    isLoading: false,
                    data
                })
            } else {
                setTodoList({
                    ...TodoList,
                    isLoading: false,
                    isError: true,
                })
            }
        })()
    }, [refresh])

    const handleDelete = async (id: number) => {
        const result = await DeleteTask(id)
        if (result) {
            setrefresh(!refresh)
        }
    }
    const handleAdd = async (task: string) => {
        const result = await AddTask(task)
        if (result) {
            setrefresh(!refresh)
        }
    }
    if (TodoList.isLoading) {
        return (<Wrapper>
            <div className={style.loading} />
        </Wrapper>)
    }
    if (TodoList.isError) {
        return (
            <Wrapper>
                <h2 className={style.notFound}>Something went wrong</h2>
            </Wrapper>
        )
    }
    return (
        <Wrapper>

            {
                TodoList.data &&
                (
                    <>
                        <Heading count={TodoList.data.length} />
                        {
                            TodoList.data.length !== 0 &&
                            <List data={TodoList.data} onClose={handleDelete} updateTask={UpdateTask} />
                        }
                        <FormComponent handleSubmit={handleAdd} />
                    </>
                )
            }




        </Wrapper>
    );
}

export default Todo;







type WrapperProps = {
    children: React.ReactNode;
}
const Wrapper: React.FC<WrapperProps> = ({ children }) => {
    return (
        <div className={style.container}>
            <div className={style.todoWrapper}>
                {children}
            </div>
        </div>
    )
}